@@ -154,8 +154,8 @@ def consommerTopics(consommateur, topics=[], batch_size=0, decode=False):
             if msg.topic() not in messages:
                 messages[msg.topic()] = []
             message = {}
-            message["value"] = msg.value().decode() if decode else msg.value()
-            message["key"] = msg.key().decode() if decode else msg.key()
+            message["value"] = decode_from_bytes(msg.value()) if decode else msg.value()
+            message["key"] = decode_from_bytes(msg.key()) if decode else msg.key()
             messages[msg.topic()].append(message)
             nb_messages_consommes += 1
         else:
